@@ -1,6 +1,7 @@
 # coding=utf-8
 
 import platform
+import sys
 
 import sentry_sdk
 import wx
@@ -17,7 +18,8 @@ from .dialog import Telemetry
 def init_telemetry():
     dsn = "https://c0b47db2a1b34f12b33ca8e78067617e:3cee11601374464dadd4b44da8a22dbd@sentry.io/152399"
 
-    sentry = sentry_sdk.init(dsn=dsn, release="4.0.3")
+    from cellprofiler import __version__
+    sentry = sentry_sdk.init(dsn=dsn, release=__version__)
 
     sentry_sdk.set_user(
         {
@@ -54,6 +56,16 @@ class App(wx.App):
         super(App, self).__init__(*args, **kwargs)
 
     def OnInit(self):
+        if platform.system() == "Windows":
+            import locale
+            # Need to startup wx in English, otherwise C++ can't load images.
+            self.locale = wx.Locale(wx.LANGUAGE_ENGLISH)
+            # Ensure Python uses the same locale as wx
+            try:
+                locale.setlocale(locale.LC_ALL, self.locale.GetName())
+            except:
+                print(f"Python rejected the system locale detected by WX ('{self.locale.GetName()}').\n"
+                      "This shouldn't cause problems, but please let us know if you encounter errors.")
         from .cpframe import CPFrame
         from cellprofiler import __version__
 
@@ -75,6 +87,13 @@ class App(wx.App):
 
         self.frame.Show()
 
+        if hasattr(sys, "frozen"):
+            from cellprofiler.gui.checkupdate import check_update
+            try:
+                check_update(self.frame)
+            except Exception as e:
+                print(f"Failed to check for updates - {e}")
+
         if get_telemetry_prompt():
             telemetry = Telemetry()
 
