@@ -107,6 +107,7 @@ ID_EDIT_REMOVE_FROM_FILE_LIST = wx.NewId()
 ID_EDIT_SHOW_FILE_LIST_IMAGE = wx.NewId()
 ID_EDIT_ENABLE_MODULE = wx.NewId()
 ID_EDIT_GO_TO_MODULE = wx.NewId()
+ID_FIND_USAGES = wx.NewId()
 
 ID_OPTIONS_PREFERENCES = wx.ID_PREFERENCES
 ID_CHECK_NEW_VERSION = wx.NewId()
@@ -823,6 +824,8 @@ class CPFrame(wx.Frame):
             "Open the plate viewer to inspect the images in the current workspace",
         )
 
+        if sys.platform == "win32":
+            self.__menu_window.AppendSeparator()
 
         self.__menu_help = Menu(self)
 
