@@ -1030,6 +1030,7 @@ class Figure(wx.Frame):
                     max=1000,
                     limited=True,
                     size=wx.Size(35, 22),
+                    integerWidth=4,
                     fractionWidth=1,
                     autoSize=False,
                     style=wx.TE_CENTRE,
@@ -2081,7 +2082,8 @@ class Figure(wx.Frame):
                     ]
                 )
             # Apply display bounds
-            image = skimage.exposure.rescale_intensity(image, in_range=(vmin, vmax))
+            if vmin is not None and vmax is not None:
+                image = skimage.exposure.rescale_intensity(image, in_range=(vmin, vmax))
         if not self.is_color_image(image):
             if not normalize:
                 if image.max() < 255:
