@@ -1083,10 +1083,10 @@ desired.
                 v = m.get_all_measurements(EXPERIMENT, feature_name)
                 if isinstance(v, numpy.ndarray) and v.dtype == numpy.uint8:
                     v = base64.b64encode(v.data)
+                elif isinstance(v, bytes):
+                    v = v.decode("unicode_escape", errors='ignore')
                 else:
                     v = str(v)
-                    if not v.isascii():
-                        v = "".join([x if ord(x) < 128 else x.decode("utf-16",error='ignore') for x in v])
                 writer.writerow((feature_name, v))
         finally:
             fd.close()
